Learn R Programming

rmetasim (version 3.1.14)

landscape.allelefreq: Calculate allele frequencies at each locus in each population

Description

Calculate allele frequencies

Usage

landscape.allelefreq(Rland,tbl.out=FALSE)

Arguments

Rland

the Rmetasim landscape object

tbl.out

return as a (three-dimensional) table if TRUE. If FALSE, return as a dataframe with categorical variables denoting the locus, population and allele.

Value

Depends on the value of tbl.out. See above.

See Also

landscape.obs.het, landscape.exp.het, landscape.Fwright, landscape.Fst

Examples

Run this code
# NOT RUN {
  exampleland <- landscape.new.example()
  exampleland <- landscape.simulate(exampleland, 4)
  landscape.allelefreq(exampleland,tbl.out=TRUE)
  landscape.allelefreq(exampleland,tbl.out=FALSE)
  rm(exampleland)
# }

Run the code above in your browser using DataLab