This function provides part of an interface between R and
SimCoal, an environment for simulating sequences and microsatellite
genotypes from coalescent trees. SimCoal can be used to simulate a
standing crop of alleles and their relationships under a wide range of
demographies. It returns haplotypes and genotypes of individuals in
Arlequin format files.
If either 'arlseq' or 'arlms' are set to NULL, their
corresponding data will not be included in the landscape (for example
if arlseq=NULL, only diploid genotypes will be imported
The genotypes in the Arlequin files are used to create
rland\$loci objects based upon their frequencies and states.
These rland\$loci sub-objects are then used to populate the
rland\$individuals sub-object.
The number of populations in the Arlequin files should be the
same among genetic locus types (sequence versus
microsatellite) and the rland\$intparam\$habitats parameter.
The per-population frequency data will be used in creating
individuals