Learn R Programming

rmetasim (version 3.1.14)

landscape.democol: return largest demographic column from a landscape

Description

return largest demographic column from a landscape

Usage

landscape.democol()

Arguments

Value

a scalar integer representing the largest column of demographic information in a landscape's individuals object

Details

Useful to write functions that will be insensitive to some changes in the individuals object (mainly addition of non-genetic information)

See Also

landscape.locus