Learn R Programming

rmetasim (version 3.1.14)

landscape.ind.freq: Return a matrix containing genotypes in 'frequency per individual' format

Description

Converts a landscape into a format that can be used in creating genind objects

Usage

landscape.ind.freq(Rland, include.states=TRUE)

Arguments

Rland

the Rmetasim landscape object

include.states

deprecated

Value

matrix

Details

This function returns a frequency by individual matrix for the landscape given in Rland

Genotypes are stored in a landscape object as columns representing allelic position. If the locus is haploid, there is a single column and if diploid, two. The allele indices are entered in each column for individual genotypes.

The 'frequency per individual' format has a column for every locusXallele combination; genotypes are represented as the frequency of particular alleles in an individuals genotype (for example freq = 1 in a column diploid means that the individual is homozygous for that column, 0.5 in two columns represents a heterozygote for the alleles represented by those two columns). This is essentially the genind format from adegenet.

See Also

landscape.freq.locnames, landscape.make.genind

Examples

Run this code
# NOT RUN {
  exampleland <- landscape.new.example() 
  exampleland <- landscape.simulate(exampleland, 25)
  head(landscape.ind.freq(exampleland))
# }

Run the code above in your browser using DataLab