Learn R Programming

rmetasim (version 3.1.14)

landscape.locus.states: return a matrix containing actual allelic states and their indices

Description

Convenience function to return a matrix containing the states of the alleles and their indicesfor a particular locus

Usage

landscape.locus.states(Rland,lnum=1,do.check=T)

Arguments

lnum

the locus to return

Rland

the Rmetasim landscape object

do.check

flag to call 'is.landscape' on input

Value

matrix

See Also

landscape.locus, landscape.states