Learn R Programming

rmetasim (version 3.1.14)

landscape.locusvec: return a vector with the locus ids for each column in the individuals component of a landscape

Description

return a vector with the locus ids for each column in the individuals component of a landscape

Usage

landscape.locusvec(Rland)

Arguments

Rland

the Rmetasim landscape object

Value

vector

See Also

landscape.populations

Examples

Run this code
# NOT RUN {
  exampleland <- landscape.new.example()
  exampleland <- landscape.simulate(exampleland, 4)
  landscape.locusvec(exampleland)
  rm(exampleland)
# }

Run the code above in your browser using DataLab