Learn R Programming

rmetasim (version 3.1.14)

landscape.make.genind: Converts genetic marker data in a landscape into a the genind format from adegenet

Description

Makes a genind object from a landscape. Populations can also be given names with an optional parameter.

Usage

landscape.make.genind(Rland)

Arguments

Rland

the Rmetasim landscape object

Value

an adegenet 'genind' object with optional population names

See Also

landscape.make.genpop