This function updates the deomgraphic parameters in a landscape for a particular epoch
landscape.modify.epoch(rland,epoch=1,S=NULL,R=NULL,M=NULL,
epochprob=NULL,startgen=NULL,extinct=NULL,
carry=NULL,localprob=NULL)landscape object, required
the epoch to modify, default 1
(default=NULL) Survivablity matrix for epoch, NULL leaves unchanged
(default=NULL) female Reproduction matrix for epoch, NULL leaves unchanged
(default=NULL) Male reporduction matrix for epoch, NULL leaves unchanged
(default=NULL) probability of choosing this epoch, NULL leaves unchanged
(default=NULL) generation in which this epoch starts, NULL leaves unchanged
(default=NULL) vector of extinction probabilities per generation for each subpopulation, NULL leaves unchanged
(default=NULL) vector of carrying capacities for each subpopulation, must be rland$intparam$habitats in length, NULL leaves unchanged
(default=NULL) vector of probabilites for choosing local demographies, must be length(rland$demography$localdem) in length, NULL leaves unchanged