Learn R Programming

rmetasim (version 3.1.14)

landscape.obs.het: Calculate observed heterozygosity

Description

Calculate observed heterozygosity from a landscape

Usage

landscape.obs.het(Rland)

Arguments

Rland

the Rmetasim landscape object

Value

A matrix with num loci columns and num populations rows. Each element reflects the observed heterozygosity for that population x locus combination

See Also

landscape.exp.het, landscape.Fst

Examples

Run this code
# NOT RUN {
  exampleland <- landscape.new.example()
  exampleland <- landscape.simulate(exampleland, 4)
  obshet <- landscape.obs.het(exampleland)
  rm(exampleland)
# }

Run the code above in your browser using DataLab