Learn R Programming

rmetasim (version 3.1.14)

landscape.ploidy: return a vector with the ploidy of each locus

Description

return a vector with the ploidy of each locus in the order they appear in the landscape

Usage

landscape.ploidy(Rland)

Arguments

Rland

the Rmetasim landscape object

Value

vector

See Also

landscape.populations

Examples

Run this code
# NOT RUN {
  exampleland <- landscape.new.example()
  landscape.ploidy(exampleland)
  rm(exampleland)
# }

Run the code above in your browser using DataLab