the number of generations/iterations to simulate, note that
landscapes will not run past the rland$intparam$totalgens value
seed
The default value of seed uses the seed set in the
calling environment. Any other value for seed uses 'set.seed()' to
reset the random number generator. landscape.simulate uses the RNG
selected by the
calling environment.
compress
If true, landscape.simulate executes a survival and carrying
capacity step before returning. In demographies with high
reproductive potential, this can significantly reduce the size of R
objects returned
adj.lambda
Tries to apply a correction to population growth
that makes the observed growth rate more closely approximate that
predicted from standard analysis eigensystem of the sum of the survival and reproduction
Lefkovitch matrices
force
Tries to simulate a landscape even if it fails the
'is.landscape' test. Do not set to TRUE unless you reall know what
you are doing