powered by
Calculate theta from a landscape based upon heterozygosity.
landscape.theta.h(rland)
the Rmetasim landscape object
A matrix with num loci columns and num populations rows. Each element reflects the estimated theta for that population x locus combination
Uses routines in the package 'ape'
landscape.theta.k, landscape.theta.s
# NOT RUN { exampleland <- landscape.new.example() exampleland <- landscape.simulate(exampleland, 4) theta.h.mat <- landscape.theta.h(exampleland) theta.h.mat # }
Run the code above in your browser using DataLab