Learn R Programming

rmetasim (version 3.1.14)

landscape.theta.k: Calculate theta using the number of alleles

Description

Calculate theta using number of alleles from a landscape.

Usage

landscape.theta.k(rland)

Arguments

rland

the Rmetasim landscape object

Value

A matrix with num loci columns and num populations rows. Each element reflects the estimated theta for that population x locus combination

Details

Uses routines in the package 'ape'

See Also

landscape.theta.h, landscape.theta.s

Examples

Run this code
# NOT RUN {
  exampleland <- landscape.new.example()
  exampleland <- landscape.simulate(exampleland, 4)

  theta.k.mat <- landscape.theta.k(exampleland)
  theta.k.mat
# }

Run the code above in your browser using DataLab