Learn R Programming

rmetasim (version 3.1.14)

landscape.theta.s: Calculate theta using segregating sites

Description

Calculate theta from a landscape based upon the number of seqregating sites.

Usage

landscape.theta.s(rland)

Arguments

rland

the Rmetasim landscape object

Value

A matrix with num loci columns and num populations rows. Each element reflects the estimated theta for that population x locus combination

Details

Uses routines in the package 'ape'

See Also

theta.k.landscape, theta.h.landscape

Examples

Run this code
# NOT RUN {
  exampleland <- landscape.new.example()
  exampleland <- landscape.simulate(exampleland, 4)
  theta.s.mat <- landscape.theta.s(exampleland)
  theta.s.mat
# }

Run the code above in your browser using DataLab