This is a wrapper for R-side functions that write landscape
data to disk.
It is probably not necessary, because of the new
landscape.make.genind() function. However, there is a single format
implemented right now: GenePop. In addition to the parameters named
above, a character string called 'title' can be passed to this
function and it will give a title at the top of the resulting genepop
file.
Former versions of this function had a "numi" parameter to specify how
many individuals to sample per population. Now use landscape.sample()
before running this one.