powered by
return largest demographic column from a landscape
landscape.democol()
a scalar integer representing the largest column of demographic information in a landscape's individuals object
Useful to write functions that will be insensitive to some changes in the individuals object (mainly addition of non-genetic information)
landscape.locus