Calculate expected heterozygosity from a landscape
Usage
landscape.exp.het(Rland)
Arguments
Rland
the Rmetasim landscape object
Value
A matrix with num loci columns and num populations rows. Each element
reflects the expected heterozygosity for that population x locus combination
Details
Calculates the expected heterozygosity in each population:
$$1-\Sigma_{i_k} p_i^2$$
where \(p\) is a vector of allele frequencies for a locus in a population.