This function returns a frequency by individual matrix for the
landscape given in Rland
Genotypes are stored in a landscape object as columns
representing allelic position. If the locus is haploid, there is a
single column and if diploid, two. The allele indices are entered in
each column for individual genotypes.
The 'frequency per individual' format has a column for every
locusXallele combination; genotypes are represented as the frequency
of particular alleles in an individuals genotype (for example freq = 1
in a column diploid means that the individual is homozygous for that
column, 0.5 in two columns represents a heterozygote for the alleles
represented by those two columns). This is essentially the genind
format from adegenet.