powered by
return a vector with the locus ids for each column in the individuals component of a landscape
landscape.locusvec(Rland)
the Rmetasim landscape object
vector
landscape.populations
# NOT RUN { exampleland <- landscape.new.example() exampleland <- landscape.simulate(exampleland, 4) landscape.locusvec(exampleland) rm(exampleland) # }
Run the code above in your browser using DataLab