powered by
Calculate observed heterozygosity from a landscape
landscape.obs.het(Rland)
the Rmetasim landscape object
A matrix with num loci columns and num populations rows. Each element reflects the observed heterozygosity for that population x locus combination
landscape.exp.het, landscape.Fst
# NOT RUN { exampleland <- landscape.new.example() exampleland <- landscape.simulate(exampleland, 4) obshet <- landscape.obs.het(exampleland) rm(exampleland) # }
Run the code above in your browser using DataLab