powered by
return a vector with the ploidy of each locus in the order they appear in the landscape
landscape.ploidy(Rland)
the Rmetasim landscape object
vector
landscape.populations
# NOT RUN { exampleland <- landscape.new.example() landscape.ploidy(exampleland) rm(exampleland) # }
Run the code above in your browser using DataLab