powered by
Calculate theta using number of alleles from a landscape.
landscape.theta.k(rland)
the Rmetasim landscape object
A matrix with num loci columns and num populations rows. Each element reflects the estimated theta for that population x locus combination
Uses routines in the package 'ape'
landscape.theta.h, landscape.theta.s
# NOT RUN { exampleland <- landscape.new.example() exampleland <- landscape.simulate(exampleland, 4) theta.k.mat <- landscape.theta.k(exampleland) theta.k.mat # }
Run the code above in your browser using DataLab