powered by
Calculate theta from a landscape based upon the number of seqregating sites.
landscape.theta.s(rland)
the Rmetasim landscape object
A matrix with num loci columns and num populations rows. Each element reflects the estimated theta for that population x locus combination
Uses routines in the package 'ape'
theta.k.landscape, theta.h.landscape
# NOT RUN { exampleland <- landscape.new.example() exampleland <- landscape.simulate(exampleland, 4) theta.s.mat <- landscape.theta.s(exampleland) theta.s.mat # }
Run the code above in your browser using DataLab